/* /////////////////////////////////////////////////////////////////////////////
 * File:        ccc.cpp
 *
 * Purpose:     Implementation file for the ccc project.
 *
 * Created:     4th September 2003
 * Updated:     21st May 2005
 *
 * Status:      Wizard-generated
 *
 * License:     (Licensed under the Synesis Software Open License)
 *
 *              Copyright (C) 2003, Gregory Peet & Matthew Wilson.
 *              All rights reserved.
 *
 *              www:        http://www.gregpeet.com/projects.php
 *                          http://www.synesis.com.au/software
 *
 *              email:      admin@gregpeet.com
 *                          software@synesis.com.au
 *
 *              This source code is placed into the public domain 2003
 *              by Gregory Peet & Matthew Wilson. There are no restrictions
 *              whatsoever to your use of the software.
 *
 *              This source code is provided by Gregory Peet & Matthew Wilson "as is"
 *              and any warranties, whether expressed or implied, including, but
 *              not limited to, the implied warranties of merchantability and
 *              fitness for a particular purpose are disclaimed. In no event
 *              shall the Gregory Peet & Matthew Wilson be liable for any direct,
 *              indirect, incidental, special, exemplary, or consequential
 *              damages (including, but not limited to, procurement of
 *              substitute goods or services; loss of use, data, or profits; or
 *              business interruption) however caused and on any theory of
 *              liability, whether in contract, strict liability, or tort
 *              (including negligence or otherwise) arising in any way out of
 *              the use of this software, even if advised of the possibility of
 *              such damage.
 *
 *              Neither the name of Gregory Peet & Matthew Wilson nor the names of
 *              any subdivisions, employees or agents of Synesis Software Pty
 *              Ltd, nor the names of any other contributors to this software
 *              may be used to endorse or promote products derived from this
 *              software without specific prior written permission.
 *
 * ////////////////////////////////////////////////////////////////////////// */


/* /////////////////////////////////////////////////////////////////////////////
 * Includes
 */

#include <windows.h>
#include <stdio.h>
#include <stdlib.h>

#include <../extras/gregpeet/compcatutil.h>	// The implementation file for this is include at the end of this source file

/* /////////////////////////////////////////////////////////////////////////////
 * Forward declarations
 */

/* Prints the usage statement. This prints by default w/o flags set at execution */
void print_usage();

/* Simple callback function for listing the names of the bad component keys */
BOOL WINAPI PrintBadKeys(char const *key_name, DWORD param);

/* ////////////////////////////////////////////////////////////////////////// */

int main(int argc, char *argv[])
{
    int		iRet		=   0;
    int		i;
	bool	bUsage		=	false;
	bool	bShowBad	=	false;
	bool	bDelete		=	false;

    printf("Component Categories Cleaner (ccc)\n");

	for(i = 1; i < argc; ++i)
	{
		const char	*arg	=	argv[i];

		if(arg[0] == '-')
		{
			switch(arg[1])
			{
				case	'p':
					bShowBad = true;
					break;
				case	'd':
					bDelete = true;
					break;
				default:
			        fprintf(stderr, "Error: Invalid argument given\n");
				case	'?':
					bUsage = true;
					break;
			}
		}
		else
		{
			/* other arguments */
		}
	}

	if(	!bShowBad &&
		!bDelete)
	{
		bUsage = true;
	}

	if(bUsage)
	{
		print_usage();

		iRet = 1;
	}
	else
	{
		ULONG cBad = 1; /* Set to non-zero, so that if
						 * not doing search, will attempt delete
						 */

		if(bShowBad)
		{
			cBad = CompCat_FindBadA(PrintBadKeys, 0);

			if( !bDelete ||
				0 == cBad)
			{
				printf("%d bad component categories\n", cBad);
			}
		}

		if( bDelete &&
			0 != cBad)
		{
			cBad = CompCat_DeleteBad();

			printf("%d bad component categories deleted\n", cBad);
		}

		iRet = 0;
	}

    return iRet;
}

/* ////////////////////////////////////////////////////////////////////////// */

void print_usage()
{
    printf("\n\tUsage: ccc [-p | -d]\n\n");
    printf("\tFlags:\n");
    printf("\t\t-p\tPrints bad components\n");
    printf("\t\t-d\tDeletes bad components\n\n");
};

BOOL WINAPI PrintBadKeys(char const *key_name, DWORD /* param */)
{
    printf("%s\n", key_name);

    return TRUE;
}

/* ////////////////////////////////////////////////////////////////////////// */

#include <../extras/gregpeet/compcatutil.cpp>

/* ////////////////////////////////////////////////////////////////////////// */
